# IBM Confidential
# OCO Source Materials
# Rational ClearCase
# (C) Copyright IBM Corp. 2005
#
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.


use Cwd 'abs_path';
use File::Basename;
use ClearCase::CurrentVersion;


my $CMD_NAME = basename($0);
my $CMD_USAGE =
    "Usage: $CMD_NAME <source> <target>\n";

if (@ARGV != 2) {
    die $CMD_USAGE;
}


my $MDEP_CCHOME = ClearCase::CurrentVersion::SetProductHomeEV;
my $MDEP_CLEARTOOL = "\"$MDEP_CCHOME/bin/cleartool\"";
my $MDEP_CLEARFSIMPORT = "\"$MDEP_CCHOME/bin/clearfsimport\"";

my $CMD_SOURCE = "$ARGV[0]";
my $CMD_TARGET_DIR = "$ARGV[1]";


if (($CMD_SOURCE_DIR = dirname($CMD_SOURCE)) eq '') {
    die "Error: Unable to derive parent directory of source element \"$CMD_SOURCE\"\n";
}

if (! -e $CMD_SOURCE || ($CMD_SOURCE_PATH = abs_path($CMD_SOURCE)) eq '') {
    die "Error: Unable to access source element \"$CMD_SOURCE\"\n";
}

if (! -e $CMD_TARGET_DIR || ($CMD_TARGET_PATH = abs_path($CMD_TARGET_DIR)) eq '') {
    die "Error: Unable to access target directory \"$CMD_TARGET_DIR\"\n";
}

# Elide any view root prefix from arguments

my $VIEW_ROOT = `$MDEP_CLEARTOOL pwv -root`; chop($VIEW_ROOT);
$CMD_SOURCE_PATH =~ s/$VIEW_ROOT//;
$CMD_SOURCE_PATH =~ s|^[A-Z]:|/|i;
$CMD_TARGET_PATH =~ s/$VIEW_ROOT//;
$CMD_TARGET_PATH =~ s|^[A-Z]:|/|i;

my $CMD_COMMENT = "\"[$CMD_NAME] copied from \\\"$CMD_SOURCE_PATH\\\" to \\\"$CMD_TARGET_PATH\\\"\"";

# Create new elements initialized with one version

if (system("$MDEP_CLEARFSIMPORT -c $CMD_COMMENT -recurse $CMD_SOURCE $CMD_TARGET_DIR")) {
    die "Error: Unable to copy source elements - correct problem and reinvoke script to resume\n";
}

# Uncatalogue original pathname

if (system("$MDEP_CLEARTOOL checkout -c $CMD_COMMENT $CMD_SOURCE_DIR")) {
    die "Error: Unable to check out source element parent directory \"$CMD_SOURCE_DIR\"\n";
}

if (system("$MDEP_CLEARTOOL rmname -c $CMD_COMMENT $CMD_SOURCE")) {
    die "Error: Unable to uncatalogue source element name \"$CMD_SOURCE\"\n";
}

if (system("$MDEP_CLEARTOOL checkin -nc $CMD_SOURCE_DIR")) {
    die "Error: Unable to check in source element parent directory \"$CMD_SOURCE_DIR\"\n";

}
